@@ -1,21 +1,7 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef PULSEOBJECT_H
@@ -28,7 +14,6 @@
 
 namespace QPulseAudio
 {
-
 class Context;
 
 class PulseObject : public QObject
@@ -38,12 +23,12 @@ class PulseObject : public QObject
     Q_PROPERTY(QString iconName READ iconName CONSTANT)
     Q_PROPERTY(QVariantMap properties READ properties NOTIFY propertiesChanged)
 public:
-    template <typename PAInfo>
+    template<typename PAInfo>
     void updatePulseObject(PAInfo *info)
     {
         m_index = info->index;
 
-        m_properties.clear();
+        QVariantMap properties;
         void *it = nullptr;
         while (const char *key = pa_proplist_iterate(info->proplist, &it)) {
             Q_ASSERT(key);
@@ -53,9 +38,13 @@ public:
                 continue;
             }
             Q_ASSERT(value);
-            m_properties.insert(QString::fromUtf8(key), QString::fromUtf8(value));
+            properties.insert(QString::fromUtf8(key), QString::fromUtf8(value));
+        }
+
+        if (m_properties != properties) {
+            m_properties = properties;
+            Q_EMIT propertiesChanged();
         }
-        Q_EMIT propertiesChanged();
     }
 
     quint32 index() const;
